street

# XMLRésuméLibrary: User Guide

state | Element Reference | street2

## Name

street — A street name, number, and other related information

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `street` element contains a street name and number, a suite or apartment number, or other similar information.

Multiple `street` elements are allowed. It is preferred to use multiple `street` elements instead of the deprecated `street2` element.

### Parents

`street` may be contained in these elements: `address`

### Attributes

`id`

  A string used to uniquely identify a street. The street may then be referred to by this identifier.

## Examples

For examples, see `address`.

state | Element Reference | street2